cfm_keystore_get_public

Function cfm_keystore_get_public 

#[unsafe(no_mangle)]
pub extern "C" fn cfm_keystore_get_public( ks: *mut FFIKeystore, module_id: *const c_char, app_id: *const c_char, identity: *const c_char, out: *mut *mut FFIKey, ) -> u32
Fetch a public key from the public compartment by identity.

On success writes the opaque key handle into *out.